@@ -436,17 +436,18 @@ def _check_single_method_spec(method_spec, fn_args):
     """
     if len(method_spec['arguments']) != len(fn_args):
         return False
-    for arg_type, arg_val in zip(method_spec['arguments'], fn_args):
+    for arg_java_type, arg_val in zip(method_spec['arguments'], fn_args):
         if isinstance(arg_val, JavaObjectShadow):
-            if arg_type not in arg_val._interfaces:
+            if arg_java_type not in arg_val._interfaces:
                 # check that it shadows object of the correct type
                 return False
         elif type(arg_val) == np.ndarray:
             # For ND Arrays, need to make sure data types match
-            if _ARRAY_TYPE_TO_NUMPY_DTYPE[arg_type] != arg_val.dtype:
+            if _ARRAY_TYPE_TO_NUMPY_DTYPE[arg_java_type] != arg_val.dtype:
                 return False
-        elif not isinstance(arg_val, _JAVA_TYPE_NAME_TO_PYTHON_TYPE[arg_type]) and \
-                    not (arg_val is None and arg_type in _JAVA_NON_PRIMITIVES): #could be null if its an object
+        elif not any([isinstance(arg_val, acceptable_type) for acceptable_type in
+                      _JAVA_TYPE_NAME_TO_CASTABLE_PYTHON_TYPE[arg_java_type]]) and \
+                    not (arg_val is None and arg_java_type in _JAVA_NON_PRIMITIVES): #could be null if its an object
             # if a type that gets converted
             return False
     return True
@@ -520,6 +521,12 @@ _JAVA_TYPE_NAME_TO_PYTHON_TYPE = {'boolean': bool, 'byte[]': np.ndarray,
                                   'int': int, 'int[]': np.ndarray, 'java.lang.String': str,
                                   'long': int, 'short': int, 'char': int, 'byte': int, 'void': None,
                                   'java.lang.Object': object}
+#type conversions that allow for autocasting
+_JAVA_TYPE_NAME_TO_CASTABLE_PYTHON_TYPE = {'boolean': {bool}, 'byte[]': {np.ndarray},
+                                  'double': {float, int}, 'double[]':  {np.ndarray}, 'float': {float},
+                                  'int': {int}, 'int[]': {np.ndarray}, 'java.lang.String': {str},
+                                  'long': {int}, 'short': {int}, 'char': {int}, 'byte': {int}, 'void': {None},
+                                  'java.lang.Object': {object}}
 _JAVA_NON_PRIMITIVES = {'byte[]', 'double[]', 'int[]', 'java.lang.String', 'java.lang.Object'}
 
 if __name__ == '__main__':
